# -*- coding: UTF-8 -*-
# @Time : 2023/6/9 16:48 
# @Author : 刘洪波


def to_html(file_path: str, save_path, overwrite=False):
    from epubs.epub_to_html import Epub2Html
    return Epub2Html(file_path, save_path, overwrite).convert()


def to_text(file_path: str, save_path, overwrite=False, func=None):
    from epubs.epub_to_text import Epub2Text
    return Epub2Text(file_path, save_path, overwrite).convert(func)



# -*- coding: UTF-8 -*-
# @Time : 2022/11/30 17:50
# @Author : 刘洪波
import ebooklib
from ebooklib import epub
from pathlib import Path
import html2text


class Epub2Text(object):
    def __init__(self, file_path: str, save_path: str = None, overwrite=False):
        self.file_path = file_path
        self.save_path = Path(save_path) if save_path else None
        self.overwrite = overwrite  # True 重新生成， False不重新生成

    def convert(self, func=None):
        """
        将epub数据转换成 text
        """
        result = []

        book = epub.read_epub(self.file_path)
        if book:
            if self.save_path:
                if self.save_path.exists():
                    print(f'{str(self.save_path)} Directory already exists.')
                    if not self.overwrite:
                        return
                else:
                    self.save_path.mkdir(exist_ok=True)
                for html in book.get_items():
                    if html.get_type() == ebooklib.ITEM_DOCUMENT:
                        self.save_data(html)
            else:
                for html in book.get_items():
                    if html.get_type() == ebooklib.ITEM_DOCUMENT:
                        content = html.get_content()
                        if func:
                            r = func(content)
                        else:
                            r = self.parse_html(content)
                        if r:
                            result.append(r)
        return result

    def save_data(self, data):
        """
        保存解析的数据（html 或 image）
        :param data:
        :return:
        """
        name = data.get_name()
        _save_path = self.save_path / data.get_name()
        if '/' in name:
            new_save_path = Path(Path(_save_path).parent)
            new_save_path.mkdir(exist_ok=True)
        with open(_save_path, 'wb') as f:
            f.write(data.get_content())

    def parse_html(self, html_content):
        """
        解析html
        :param html_content:
        :return:
        """
        h = html2text.HTML2Text()
        h.ignore_links = True
        h.ignore_images = True
        h.ignore_tables = True
        res = []
        r = h.handle(html_content.decode('utf-8'))
        for i in r.strip().split('\n'):
            if i.strip():
                res.append(i.strip())
        return res



# -*- coding: UTF-8 -*-
# @Time : 2022/8/17 16:07 
# @Author : 刘洪波

import setuptools
from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='epubs',
    version='0.0.2',
    packages=setuptools.find_packages(),
    url='https://gitee.com/maxbanana',
    license='Apache',
    author='hongbo liu',
    author_email='782027465@qq.com',
    description='A Conversion Tool for EPUB',
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=['ebooklib>=0.17.1', 'html2text'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)



# -*- coding: UTF-8 -*-
# @Time : 2022/8/11 15:25 
# @Author : 刘洪波

import ebooklib
from ebooklib import epub
from pathlib import Path
"""
将epub文件转换成html
"""


class Epub2Html(object):
    def __init__(self, file_path: str, save_path: str, overwrite=False):
        self.file_path = file_path
        self.save_path = Path(save_path)
        self.overwrite = overwrite  # True 重新生成， False不重新生成

    def convert(self):
        """
        将epub数据转换成 hmtl 与 image
        :return:
        """
        try:
            book = epub.read_epub(self.file_path)
            if book:
                if self.save_path.exists():
                    print(f'{str(self.save_path)} Directory already exists.')
                    if not self.overwrite:
                        return
                else:
                    self.save_path.mkdir(exist_ok=True)
                for image in book.get_items_of_type(ebooklib.ITEM_IMAGE):
                    self.save_data(image)
                for html in book.get_items():
                    if html.get_type() == ebooklib.ITEM_DOCUMENT:
                        self.save_data(html)
        except Exception as e:
            print(e)

    def save_data(self, data):
        """
        保存解析的数据（html 或 image）
        :param data:
        :return:
        """
        name = data.get_name()
        _save_path = self.save_path / data.get_name()
        if '/' in name:
            new_save_path = Path(Path(_save_path).parent)
            new_save_path.mkdir(exist_ok=True)
        with open(_save_path, 'wb') as f:
            f.write(data.get_content())


